@@ -34,69 +34,67 @@
 #'
 #' @examples
 #' data("logd1k")
-#' x = logd1k$x
-#' y = logd1k$y
+#' x <- logd1k$x
+#' y <- logd1k$y
 #'
 #' set.seed(42)
-#' fit = enspls.fit(
-#'   x, y, reptimes = 5, maxcomp = 3,
-#'   alpha = c(0.3, 0.6, 0.9))
+#' fit <- enspls.fit(
+#'   x, y,
+#'   reptimes = 5, maxcomp = 3,
+#'   alpha = c(0.3, 0.6, 0.9)
+#' )
 #' print(fit)
 #' predict(fit, newx = x)
-
-enspls.fit = function(
+enspls.fit <- function(
   x, y,
-  maxcomp  = 5L,
-  cvfolds  = 5L,
-  alpha    = seq(0.2, 0.8, 0.2),
+  maxcomp = 5L,
+  cvfolds = 5L,
+  alpha = seq(0.2, 0.8, 0.2),
   reptimes = 500L,
-  method   = c('mc', 'boot'),
-  ratio    = 0.8,
+  method = c("mc", "boot"),
+  ratio = 0.8,
   parallel = 1L) {
+  if (missing(x) | missing(y)) stop("Please specify both x and y")
 
-  if (missing(x) | missing(y)) stop('Please specify both x and y')
+  method <- match.arg(method)
 
-  method = match.arg(method)
+  x.row <- nrow(x)
+  samp.idx <- vector("list", reptimes)
 
-  x.row = nrow(x)
-  samp.idx = vector('list', reptimes)
-
-  if (method == 'mc') {
-    for (i in 1L:reptimes)
-      samp.idx[[i]] = sample(1L:x.row, round(x.row * ratio))
+  if (method == "mc") {
+    for (i in 1L:reptimes) {
+      samp.idx[[i]] <- sample(1L:x.row, round(x.row * ratio))
+    }
   }
 
-  if (method == 'boot') {
-    for (i in 1L:reptimes)
-      samp.idx[[i]] = sample(1L:x.row, x.row, replace = TRUE)
+  if (method == "boot") {
+    for (i in 1L:reptimes) {
+      samp.idx[[i]] <- sample(1L:x.row, x.row, replace = TRUE)
+    }
   }
 
   if (parallel < 1.5) {
-
-    modellist = vector('list', reptimes)
+    modellist <- vector("list", reptimes)
     for (i in 1L:reptimes) {
-      xtmp = x[samp.idx[[i]], ]
-      ytmp = y[samp.idx[[i]]]
-      modellist[[i]] = enspls.fit.core(
-        xtmp, ytmp, maxcomp, cvfolds, alpha)
+      xtmp <- x[samp.idx[[i]], ]
+      ytmp <- y[samp.idx[[i]]]
+      modellist[[i]] <- enspls.fit.core(
+        xtmp, ytmp, maxcomp, cvfolds, alpha
+      )
     }
-
   } else {
-
     registerDoParallel(parallel)
-    modellist = foreach(i = 1L:reptimes) %dopar% {
-      xtmp = x[samp.idx[[i]], ]
-      ytmp = y[samp.idx[[i]]]
+    modellist <- foreach(i = 1L:reptimes) %dopar% {
+      xtmp <- x[samp.idx[[i]], ]
+      ytmp <- y[samp.idx[[i]]]
       enspls.fit.core(xtmp, ytmp, maxcomp, cvfolds, alpha)
     }
-
   }
 
-  names(modellist) = paste0('spls_model_', 1L:length(modellist))
-  class(modellist) = 'enspls.fit'
+  names(modellist) <- paste0("spls_model_", 1L:length(modellist))
+  class(modellist) <- "enspls.fit"
 
   modellist
-
 }
 
 #' core function for enspls.fit
@@ -112,43 +110,45 @@ enspls.fit = function(
 #'
 #' @keywords internal
 
-enspls.fit.core = function(xtmp, ytmp, maxcomp, cvfolds, alpha) {
-
+enspls.fit.core <- function(xtmp, ytmp, maxcomp, cvfolds, alpha) {
   invisible(capture.output(
     spls.cvfit <- cv.spls(
       xtmp,
       ytmp,
-      fold    = cvfolds,
-      K       = maxcomp,
-      eta     = alpha,
+      fold = cvfolds,
+      K = maxcomp,
+      eta = alpha,
       scale.x = TRUE,
       scale.y = FALSE,
-      plot.it = FALSE)))
+      plot.it = FALSE
+    )
+  ))
 
   # select best component number and alpha using adjusted CV
-  cv.bestcomp  = spls.cvfit$'K.opt'
-  cv.bestalpha = spls.cvfit$'eta.opt'
+  cv.bestcomp <- spls.cvfit$"K.opt"
+  cv.bestalpha <- spls.cvfit$"eta.opt"
 
   # clean up spls.cvfit object
   rm(spls.cvfit)
 
-  spls.fit = spls(
+  spls.fit <- spls(
     xtmp,
     ytmp,
-    K       = cv.bestcomp,
-    eta     = cv.bestalpha,
+    K = cv.bestcomp,
+    eta = cv.bestalpha,
     scale.x = TRUE,
-    scale.y = FALSE)
+    scale.y = FALSE
+  )
 
   # save cv.bestcomp and cv.bestalpha for predict.enspls
-  enspls.core.fit = list(
-    'spls.fit' = spls.fit,
-    'cv.bestcomp' = cv.bestcomp,
-    'cv.bestalpha' = cv.bestalpha)
+  enspls.core.fit <- list(
+    "spls.fit" = spls.fit,
+    "cv.bestcomp" = cv.bestcomp,
+    "cv.bestalpha" = cv.bestalpha
+  )
 
   # clean up spls.fit object
   rm(spls.fit)
 
   enspls.core.fit
-
 }
